Index: src/libdvdcss.c
===================================================================
--- src/libdvdcss.c	(revision 237)
+++ src/libdvdcss.c	(working copy)
@@ -366,27 +366,7 @@
 
     if( dvdcss->b_ioctls )
     {
-        i_ret = _dvdcss_test( dvdcss );
-
-        if( i_ret == -3 )
-        {
-            print_debug( dvdcss, "scrambled disc on a region-free RPC-II "
-                                 "drive: possible failure, but continuing "
-                                 "anyway" );
-        }
-        else if( i_ret < 0 )
-        {
-            /* Disable the CSS ioctls and hope that it works? */
-            print_debug( dvdcss,
-                         "could not check whether the disc was scrambled" );
-            dvdcss->b_ioctls = 0;
-        }
-        else
-        {
-            print_debug( dvdcss, i_ret ? "disc is scrambled"
-                                       : "disc is unscrambled" );
-            dvdcss->b_scrambled = i_ret;
-        }
+        _dvdcss_test( dvdcss );
     }
 
     memset( dvdcss->css.p_disc_key, 0, KEY_SIZE );
Index: src/css.c
===================================================================
--- src/css.c	(revision 236)
+++ src/css.c	(working copy)
@@ -90,46 +90,31 @@
 /*****************************************************************************
  * _dvdcss_test: check if the disc is encrypted or not
  *****************************************************************************
- * Return values:
- *   1: DVD is scrambled but can be read
- *   0: DVD is not scrambled and can be read
- *  -1: could not get "copyright" information
- *  -2: could not get RPC information (reading the disc might be possible)
- *  -3: drive is RPC-II, region is not set, and DVD is scrambled: the RPC
- *      scheme will prevent us from reading the scrambled data
+ * Unsets b_scrambled if the disc is certainly not scrambled.
  *****************************************************************************/
-int _dvdcss_test( dvdcss_t dvdcss )
+void _dvdcss_test( dvdcss_t dvdcss )
 {
     char const *psz_type, *psz_rpc;
-    int i_ret, i_copyright, i_type, i_mask, i_rpc;
+    int i_ret, i_copyright = 1, i_type, i_mask, i_rpc;
 
     i_ret = ioctl_ReadCopyright( dvdcss->i_fd, 0 /* i_layer */, &i_copyright );
 
-#ifdef WIN32
     if( i_ret < 0 )
     {
         /* Maybe we didn't have enough privileges to read the copyright
          * (see ioctl_ReadCopyright comments).
-         * Apparently, on unencrypted DVDs _dvdcss_disckey() always fails, so
-         * we can check this as a workaround. */
-        i_ret = 0;
-        i_copyright = 1;
-        if( _dvdcss_disckey( dvdcss ) < 0 )
-        {
-            i_copyright = 0;
-        }
-    }
-#endif
-
-    if( i_ret < 0 )
-    {
+         * On unencrypted DVDs _dvdcss_disckey() always fails, however
+         * it will always fail if ioctls do not work at all so we cannot
+         * use that either.
+         * We just assume the disc will be scrambled, the per-title checks
+         * should still handle this fine. */
         /* Since it's the first ioctl we try to issue, we add a notice */
         print_error( dvdcss, "css error: could not get \"copyright\""
                      " information, make sure there is a DVD in the drive,"
                      " and that you have used the correct device node." );
-
-        return -1;
     }
+    else
+        dvdcss->b_scrambled = i_copyright;
 
     print_debug( dvdcss, "disc reports copyright information 0x%x",
                          i_copyright );
@@ -138,8 +123,8 @@
 
     if( i_ret < 0 )
     {
-        print_error( dvdcss, "css error: could not get RPC status" );
-        return -2;
+        print_error( dvdcss, "css error: could not get RPC status, region-free drive?" );
+        return;
     }
 
     switch( i_rpc )
@@ -165,10 +150,7 @@
     {
         print_error( dvdcss, "css error: drive will prevent access to "
                              "scrambled data" );
-        return -3;
     }
-
-    return i_copyright ? 1 : 0;
 }
 
 /*****************************************************************************
Index: src/css.h
===================================================================
--- src/css.h	(revision 236)
+++ src/css.h	(working copy)
@@ -54,7 +54,7 @@
 /*****************************************************************************
  * Prototypes in css.c
  *****************************************************************************/
-int   _dvdcss_test        ( dvdcss_t );
+void  _dvdcss_test        ( dvdcss_t );
 int   _dvdcss_title       ( dvdcss_t, int );
 int   _dvdcss_disckey     ( dvdcss_t );
 int   _dvdcss_titlekey    ( dvdcss_t, int , dvd_key_t );
